@@ -153,8 +153,8 @@ const double vpmb_conservatism_lvls[] = { 1.0, 1.05, 1.12, 1.22, 1.35 };
 
 #define TISSUE_ARRAY_SZ sizeof(ds->tissue_n2_sat)
 
-int sumx, sum1;
-long sumxx;
+int  sum1;
+long sumx, sumxx;
 double sumy, sumxy;
 
 double get_crit_radius_He()
@@ -543,8 +543,7 @@ void clear_deco(struct deco_state *ds, double surface_pressure)
 		ds->n2_regen_radius[ci] = get_crit_radius_N2();
 		ds->he_regen_radius[ci] = get_crit_radius_He();
 	}
-	ds->gf_low_pressure_this_dive = surface_pressure;
-		ds->gf_low_pressure_this_dive += buehlmann_config.gf_low_position_min;
+	ds->gf_low_pressure_this_dive = surface_pressure + buehlmann_config.gf_low_position_min;
 	ds->max_ambient_pressure = 0.0;
 }
 
@@ -650,7 +649,7 @@ double regressionb()
 
 void reset_regression()
 {
-	sumx = sum1 = 0;
-	sumxx = 0L;
+	sum1 = 0;
+	sumxx = sumx = 0L;
 	sumy = sumxy = 0.0;
 }
