@@ -4,6 +4,7 @@
 
 #include <stdlib.h>
 #include <stdint.h>
+#include <stdbool.h>
 #include <time.h>
 #include <math.h>
 #include <zip.h>
@@ -27,17 +28,22 @@
 
 #define IS_FP_SAME(_a, _b) (fabs((_a) - (_b)) <= 0.000001 * MAX(fabs(_a), fabs(_b)))
 
-static inline int same_string(const char *a, const char *b)
+static inline bool same_string(const char *a, const char *b)
 {
 	return !strcmp(a ?: "", b ?: "");
 }
 
-static inline int same_string_caseinsensitive(const char *a, const char *b)
+static inline bool same_string_caseinsensitive(const char *a, const char *b)
 {
 	return !strcasecmp(a ?: "", b ?: "");
 }
 
-static inline int includes_string_caseinsensitive(const char *haystack, const char *needle)
+static inline bool empty_string(const char *s)
+{
+	return !s || !*s;
+}
+
+static inline bool includes_string_caseinsensitive(const char *haystack, const char *needle)
 {
 	if (!needle)
 		return 1; /* every string includes the NULL string */
@@ -66,8 +72,6 @@ static inline char *copy_string(const char *s)
 
 #ifdef __cplusplus
 extern "C" {
-#else
-#include <stdbool.h>
 #endif
 
 extern int last_xml_version;
@@ -110,6 +114,13 @@ typedef struct
 	const char *description; /* "integrated", "belt", "ankle" */
 } weightsystem_t;
 
+struct icd_data { // This structure provides communication between function isobaric_counterdiffusion() and the calling software.
+	int dN2;      // The change in fraction (permille) of nitrogen during the change
+	int dHe;      // The change in fraction (permille) of helium during the change
+};
+
+extern bool isobaric_counterdiffusion(struct gasmix *oldgasmix, struct gasmix *newgasmix, struct icd_data *results);
+
 /*
  * Events are currently based straight on what libdivecomputer gives us.
  *  We need to wrap these into our own events at some point to remove some of the limitations.
@@ -265,7 +276,6 @@ void taglist_init_global();
 void taglist_free(struct tag_entry *tag_list);
 
 bool taglist_contains(struct tag_entry *tag_list, const char *tag);
-bool taglist_equal(struct tag_entry *tl1, struct tag_entry *tl2);
 int count_dives_with_tag(const char *tag);
 int count_dives_with_person(const char *person);
 int count_dives_with_location(const char *location);
@@ -292,7 +302,7 @@ struct extra_data {
  */
 struct divecomputer {
 	timestamp_t when;
-	duration_t duration, surfacetime;
+	duration_t duration, surfacetime, last_manual_time;
 	depth_t maxdepth, meandepth;
 	temperature_t airtemp, watertemp;
 	pressure_t surface_pressure;
@@ -525,7 +535,7 @@ static inline depth_t gas_mnd(struct gasmix *mix, depth_t end, struct dive *dive
 
 #define SURFACE_THRESHOLD 750 /* somewhat arbitrary: only below 75cm is it really diving */
 
-extern short autogroup;
+extern bool autogroup;
 /* random threashold: three days without diving -> new trip
  * this works very well for people who usually dive as part of a trip and don't
  * regularly dive at a local facility; this is why trips are an optional feature */
@@ -708,9 +718,8 @@ extern "C" {
 #endif
 
 extern int report_error(const char *fmt, ...);
-extern void report_message(const char *msg);
 extern const char *get_error_string(void);
-extern void set_error_cb(void(*cb)(void));
+extern void set_error_cb(void(*cb)(char *));	// Callback takes ownership of passed string
 
 extern struct dive *find_dive_including(timestamp_t when);
 extern bool dive_within_time_range(struct dive *dive, timestamp_t when, timestamp_t offset);
@@ -735,7 +744,6 @@ extern int parse_dlf_buffer(unsigned char *buffer, size_t size);
 extern int parse_file(const char *filename);
 extern int parse_csv_file(const char *filename, char **params, int pnr, const char *csvtemplate);
 extern int parse_seabear_log(const char *filename);
-extern int parse_seabear_csv_file(const char *filename, char **params, int pnr, const char *csvtemplate);
 extern int parse_txt_file(const char *filename, const char *csv);
 extern int parse_manual_file(const char *filename, char **params, int pnr);
 extern int save_dives(const char *filename);
@@ -768,7 +776,6 @@ extern void subsurface_console_init(void);
 extern void subsurface_console_exit(void);
 extern bool subsurface_user_is_root(void);
 
-extern void shift_times(const timestamp_t amount);
 extern timestamp_t get_times();
 
 extern xsltStylesheetPtr get_stylesheet(const char *name);
@@ -791,8 +798,6 @@ extern void finish_sample(struct divecomputer *dc);
 extern void add_sample_pressure(struct sample *sample, int sensor, int mbar);
 extern int legacy_format_o2pressures(struct dive *dive, struct divecomputer *dc);
 
-extern bool has_hr_data(struct divecomputer *dc);
-
 extern void sort_table(struct dive_table *table);
 extern struct dive *fixup_dive(struct dive *dive);
 extern void fixup_dc_duration(struct divecomputer *dc);
@@ -846,7 +851,6 @@ extern int total_weight(struct dive *);
 #define DIVE_ERROR_PARSE 1
 #define DIVE_ERROR_PLAN 2
 
-const char *weekday(int wday);
 const char *monthname(int mon);
 
 #define UTF8_DEGREE "\xc2\xb0"
@@ -988,7 +992,6 @@ extern bool cylinder_nodata(const cylinder_t *cyl);
 extern bool cylinder_none(void *_data);
 extern bool weightsystem_none(void *_data);
 extern bool no_weightsystems(weightsystem_t *ws);
-extern bool weightsystems_equal(weightsystem_t *ws1, weightsystem_t *ws2);
 extern void remove_cylinder(struct dive *dive, int idx);
 extern void remove_weightsystem(struct dive *dive, int idx);
 extern void reset_cylinders(struct dive *dive, bool track_gas);
@@ -1026,8 +1029,6 @@ extern volume_t string_to_volume(const char *str, pressure_t workp);
 extern fraction_t string_to_fraction(const char *str);
 extern void average_max_depth(struct diveplan *dive, int *avg_depth, int *max_depth);
 
-extern struct dive_table downloadTable;
-
 #include "pref.h"
 
 #endif // DIVE_H
