@@ -189,14 +189,17 @@ uint32_t create_divesite_uuid(const char *name, timestamp_t divetime)
 {
 	if (name == NULL)
 		name ="";
-	unsigned char hash[20];
+	union {
+		unsigned char hash[20];
+		uint32_t i;
+	} u;
 	SHA_CTX ctx;
 	SHA1_Init(&ctx);
 	SHA1_Update(&ctx, &divetime, sizeof(timestamp_t));
 	SHA1_Update(&ctx, name, strlen(name));
-	SHA1_Final(hash, &ctx);
+	SHA1_Final(u.hash, &ctx);
 	// now return the first 32 of the 160 bit hash
-	return *(uint32_t *)hash;
+	return u.i;
 }
 
 /* allocate a new site and add it to the table */
@@ -236,9 +239,9 @@ uint32_t create_dive_site_with_gps(const char *name, degrees_t latitude, degrees
 /* a uuid is always present - but if all the other fields are empty, the dive site is pointless */
 bool dive_site_is_empty(struct dive_site *ds)
 {
-	return same_string(ds->name, "") &&
-	       same_string(ds->description, "") &&
-	       same_string(ds->notes, "") &&
+	return empty_string(ds->name) &&
+	       empty_string(ds->description) &&
+	       empty_string(ds->notes) &&
 	       ds->latitude.udeg == 0 &&
 	       ds->longitude.udeg == 0;
 }
@@ -251,8 +254,10 @@ void copy_dive_site_taxonomy(struct dive_site *orig, struct dive_site *copy)
 		if (copy->taxonomy.category == NULL)
 			copy->taxonomy.category = alloc_taxonomy();
 		for (int i = 0; i < TC_NR_CATEGORIES; i++) {
-			if (i < copy->taxonomy.nr)
+			if (i < copy->taxonomy.nr) {
 				free((void *)copy->taxonomy.category[i].value);
+				copy->taxonomy.category[i].value = NULL;
+			}
 			if (i < orig->taxonomy.nr) {
 				copy->taxonomy.category[i] = orig->taxonomy.category[i];
 				copy->taxonomy.category[i].value = copy_string(orig->taxonomy.category[i].value);
