@@ -259,7 +259,7 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 	struct event *ev;
 	cylinder_t *cyl;
 	int oldpo2 = 0;
-	int lasttime = 0;
+	int lasttime = 0, last_manual_point = 0;
 	depth_t lastdepth = {.mm = 0};
 	int lastcylid;
 	enum dive_comp_type type = dive->dc.divemode;
@@ -342,6 +342,7 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 		sample[-1].setpoint.mbar = po2;
 		sample->setpoint.mbar = po2;
 		sample->time.seconds = lasttime = time;
+		if (dp->entered) last_manual_point = dp->time;
 		sample->depth = lastdepth = depth;
 		sample->manually_entered = dp->entered;
 		sample->sac.mliter = dp->entered ? prefs.bottomsac : prefs.decosac;
@@ -354,6 +355,8 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 		finish_sample(dc);
 		dp = dp->next;
 	}
+	dive->dc.last_manual_time.seconds = last_manual_point;
+
 	dc->divemode = type;
 #if DEBUG_PLAN & 32
 	save_dive(stdout, &displayed_dive);
@@ -779,7 +782,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 			clock += timestep;
 		} while (trial_ascent(ds, 0, depth, 0, avg_depth, bottom_time, &dive->cylinder[current_cylinder].gasmix,
 				      po2, diveplan->surface_pressure / 1000.0, dive) &&
-			 enough_gas(current_cylinder));
+			 enough_gas(current_cylinder) && clock < 6 * 3600);
 
 		// We did stay one DECOTIMESTEP too many.
 		// In the best of all worlds, we would roll back also the last add_segment in terms of caching deco state, but
