@@ -30,16 +30,64 @@ int diveplan_duration(struct diveplan *diveplan)
 	return (duration + 30) / 60;
 }
 
+/* Add the icd results of one trimix gas change to the dive plan html buffer. Two rows are added to the table, one
+ * indicating fractions of gas, the other indication partial pressures of gas. This function makes use of the
+ * icd_data structure that was filled with information by the function isobaric_counterdiffusion().
+ * Parameters: 1) Pointer to the output buffer position at which writing should start.
+ *             2) The size of the part of the unused output buffer that remains unused.
+ *             3) The data structure containing icd calculation results: icdvalues.
+ *             4) A boolean value indicating whether a table header should be written before the data. Only during 1st call.
+ *             5) Pointers to gas mixes in the gas change: gas-from and gas-to.
+ * Returns:    The size of the output buffer that has been used after the new results have been added.
+ */
+int add_icd_entry(char *icdbuffer, unsigned int maxsize, struct icd_data *icdvalues, bool printheader, int time_seconds, int ambientpressure_mbar, struct gasmix *gas_from, struct gasmix *gas_to)
+{
+	int len = 0;
+	if (printheader) { // Create a table description and a table header if no icd data have been written yet.
+		len = snprintf(icdbuffer + len, maxsize - len, "<div>%s:",
+			translate("gettextFromC","Isobaric counterdiffusion information"));
+		len += snprintf(icdbuffer + len, maxsize - len, "<table><tr><td align='left'><b>%s</b></td>",
+			translate("gettextFromC", "runtime"));
+		len += snprintf(icdbuffer + len, maxsize - len, "<td align='center'><b>%s</b></td>",
+			translate("gettextFromC", "gaschange"));
+		len += snprintf(icdbuffer + len, maxsize - len, "<td style='padding-left: 15px;'><b>%s</b></td>",
+			translate("gettextFromC", "&#916;He"));
+		len += snprintf(icdbuffer + len, maxsize - len, "<td style='padding-left: 20px;'><b>%s</b></td>",
+			translate("gettextFromC", "&#916;N&#8322;"));
+		len += snprintf(icdbuffer + len, maxsize - len, "<td style='padding-left: 10px;'><b>%s</b></td></tr>",
+			translate("gettextFromC", "max &#916;N&#8322;"));
+	}		// Add one entry to the icd table:
+	len += snprintf(icdbuffer + len, maxsize - len, 
+		"<tr><td rowspan='2' style= 'vertical-align:top;'>%3d%s</td>"
+		"<td rowspan=2 style= 'vertical-align:top;'>%s&#10137;",
+		(time_seconds + 30) / 60, translate("gettextFromC", "min"), gasname(gas_from));
+	len += snprintf(icdbuffer + len, maxsize - len, 
+		"%s</td><td style='padding-left: 10px;'>%+5.1f%%</td>"
+		"<td style= 'padding-left: 15px; color:%s;'>%+5.1f%%</td>"
+		"<td style='padding-left: 15px;'>%+5.1f%%</td></tr>"
+		"<tr><td style='padding-left: 10px;'>%+5.2f%s</td>"
+		"<td style='padding-left: 15px; color:%s;'>%+5.2f%s</td>"
+		"<td style='padding-left: 15px;'>%+5.2f%s</td></tr>",
+		gasname(gas_to), icdvalues->dHe / 10.0, 
+		((5 * icdvalues->dN2) > -icdvalues->dHe) ? "red" : "#383838", icdvalues->dN2 / 10.0 , 0.2 * (-icdvalues->dHe / 10.0), 
+		ambientpressure_mbar * icdvalues->dHe / 1e6f, translate("gettextFromC", "bar"), ((5 * icdvalues->dN2) > -icdvalues->dHe) ? "red" : "#383838",
+		ambientpressure_mbar * icdvalues->dN2 / 1e6f, translate("gettextFromC", "bar"), 
+		ambientpressure_mbar * -icdvalues->dHe / 5e6f, translate("gettextFromC", "bar"));
+	return len;
+}
 
 void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_disclaimer, int error)
 {
 	const unsigned int sz_buffer = 2000000;
 	const unsigned int sz_temp = 100000;
+	const unsigned int sz_icdbuf = 10000;
 	char *buffer = (char *)malloc(sz_buffer);
 	char *temp = (char *)malloc(sz_temp);
+	char *icdbuffer = (char *)malloc(sz_icdbuf);
 	const char *deco, *segmentsymbol;
 	static char buf[1000];
 	int len, lastdepth = 0, lasttime = 0, lastsetpoint = -1, newdepth = 0, lastprintdepth = 0, lastprintsetpoint = -1;
+	int icdlen = 0;
 	struct gasmix lastprintgasmix = {{ -1 }, { -1 }};
 	struct divedatapoint *dp = diveplan->dp;
 	bool plan_verbatim = prefs.verbatim_plan;
@@ -49,9 +97,10 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 	bool gaschange_after = !plan_verbatim;
 	bool gaschange_before;
 	bool lastentered = true;
+	bool icdwarning = false, icdtableheader = true;
 	struct divedatapoint *nextdp = NULL;
 	struct divedatapoint *lastbottomdp = NULL;
-
+	struct icd_data icdvalues;
 
 	if (decoMode() == VPMB) {
 		deco = translate("gettextFromC", "VPM-B");
@@ -60,81 +109,75 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 	}
 
 	snprintf(buf, sizeof(buf), translate("gettextFromC", "DISCLAIMER / WARNING: THIS IS A NEW IMPLEMENTATION OF THE %s "
-				"ALGORITHM AND A DIVE PLANNER IMPLEMENTATION BASED ON THAT WHICH HAS "
-				"RECEIVED ONLY A LIMITED AMOUNT OF TESTING. WE STRONGLY RECOMMEND NOT TO "
-				"PLAN DIVES SIMPLY BASED ON THE RESULTS GIVEN HERE."), deco);
+		"ALGORITHM AND A DIVE PLANNER IMPLEMENTATION BASED ON THAT WHICH HAS "
+		"RECEIVED ONLY A LIMITED AMOUNT OF TESTING. WE STRONGLY RECOMMEND NOT TO "
+		"PLAN DIVES SIMPLY BASED ON THE RESULTS GIVEN HERE."), deco);
 	disclaimer = buf;
 
-	if (!dp) {
-		free((void *)buffer);
-		free((void *)temp);
-		return;
-	}
+	if (!dp)
+		goto finished;
 
 	if (error) {
 		snprintf(temp, sz_temp, "%s",
-			 translate("gettextFromC", "Decompression calculation aborted due to excessive time"));
+			translate("gettextFromC", "Decompression calculation aborted due to excessive time"));
 		snprintf(buffer, sz_buffer, "<span style='color: red;'>%s </span> %s<br>",
-				translate("gettextFromC", "Warning:"), temp);
+			translate("gettextFromC", "Warning:"), temp);
 		dive->notes = strdup(buffer);
-
-		free((void *)buffer);
-		free((void *)temp);
-		return;
+		goto finished;
 	}
 
 	len = show_disclaimer ? snprintf(buffer, sz_buffer, "<div><b>%s</b><br></div>", disclaimer) : 0;
 
 	if (diveplan->surface_interval < 0) {
 		len += snprintf(buffer + len, sz_buffer - len, "<div><b>%s (%s) %s<br>",
-				translate("gettextFromC", "Subsurface"),
-				subsurface_canonical_version(),
-				translate("gettextFromC", "dive plan</b> (overlapping dives detected)"));
-				dive->notes = strdup(buffer);
-				free((void *)buffer);
-				free((void *)temp);
-				return;
+			translate("gettextFromC", "Subsurface"),
+			subsurface_canonical_version(),
+			translate("gettextFromC", "dive plan</b> (overlapping dives detected)"));
+		dive->notes = strdup(buffer);
+		free((void *)buffer);
+		free((void *)temp);
+		return;
 	} else if (diveplan->surface_interval >= 48 * 60 *60) {
 		const char *current_date = get_current_date();
 		len += snprintf(buffer + len, sz_buffer - len, "<div><b>%s (%s) %s %s</b><br>",
-				translate("gettextFromC", "Subsurface"),
-				subsurface_canonical_version(),
-				translate("gettextFromC", "dive plan</b> created on"),
-				current_date);
+			translate("gettextFromC", "Subsurface"),
+			subsurface_canonical_version(),
+			translate("gettextFromC", "dive plan</b> created on"),
+			current_date);
 		free((void *)current_date);
 	} else {
 		const char *current_date = get_current_date();
 		len += snprintf(buffer + len, sz_buffer - len, "<div><b>%s (%s) %s %d:%02d) %s %s<br>",
-				translate("gettextFromC", "Subsurface"),
-				subsurface_canonical_version(),
-				translate("gettextFromC", "dive plan</b> (surface interval "),
-				FRACTION(diveplan->surface_interval / 60, 60),
-				translate("gettextFromC", "created on"),
-				current_date);
+			translate("gettextFromC", "Subsurface"),
+			subsurface_canonical_version(),
+			translate("gettextFromC", "dive plan</b> (surface interval "),
+			FRACTION(diveplan->surface_interval / 60, 60),
+			translate("gettextFromC", "created on"),
+			current_date);
 		free((void *)current_date);
 	}
 
 	if (prefs.display_variations && decoMode() != RECREATIONAL)
 		len += snprintf(buffer + len, sz_buffer - len, translate("gettextFromC", "Runtime: %dmin%s"),
-				diveplan_duration(diveplan), "VARIATIONS<br></div>");
+			diveplan_duration(diveplan), "VARIATIONS<br></div>");
 	else
 		len += snprintf(buffer + len, sz_buffer - len, translate("gettextFromC", "Runtime: %dmin<br></div>"),
-				diveplan_duration(diveplan));
-
+			diveplan_duration(diveplan));
 
 	if (!plan_verbatim) {
 		len += snprintf(buffer + len, sz_buffer - len, "<table><thead><tr><th></th><th>%s</th>",
-				translate("gettextFromC", "depth"));
+			translate("gettextFromC", "depth"));
 		if (plan_display_duration)
 			len += snprintf(buffer + len, sz_buffer - len, "<th style='padding-left: 10px;'>%s</th>",
-					translate("gettextFromC", "duration"));
+				translate("gettextFromC", "duration"));
 		if (plan_display_runtime)
 			len += snprintf(buffer + len, sz_buffer - len, "<th style='padding-left: 10px;'>%s</th>",
-					translate("gettextFromC", "runtime"));
+				translate("gettextFromC", "runtime"));
 		len += snprintf(buffer + len, sz_buffer - len,
 				"<th style='padding-left: 10px; float: left;'>%s</th></tr></thead><tbody style='float: left;'>",
 				translate("gettextFromC", "gas"));
 	}
+
 	do {
 		struct gasmix gasmix, newgasmix = {};
 		const char *depth_unit;
@@ -179,41 +222,40 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 			 */
 			if (dp->depth.mm != lastprintdepth) {
 				if (plan_display_transitions || dp->entered || !dp->next || (gaschange_after && dp->next && dp->depth.mm != nextdp->depth.mm)) {
-					if (dp->setpoint)
+					if (dp->setpoint) {
 						snprintf(temp, sz_temp, translate("gettextFromC", "Transition to %.*f %s in %d:%02d min - runtime %d:%02u on %s (SP = %.1fbar)"),
 							 decimals, depthvalue, depth_unit,
 							 FRACTION(dp->time - lasttime, 60),
 							 FRACTION(dp->time, 60),
 							 gasname(&gasmix),
 							 (double) dp->setpoint / 1000.0);
-
-					else
+					} else {
 						snprintf(temp, sz_temp, translate("gettextFromC", "Transition to %.*f %s in %d:%02d min - runtime %d:%02u on %s"),
 							 decimals, depthvalue, depth_unit,
 							 FRACTION(dp->time - lasttime, 60),
 							 FRACTION(dp->time, 60),
 							 gasname(&gasmix));
-
+					}
 					len += snprintf(buffer + len, sz_buffer - len, "%s<br>", temp);
 				}
 				newdepth = dp->depth.mm;
 				lasttime = dp->time;
 			} else {
 				if ((nextdp && dp->depth.mm != nextdp->depth.mm) || gaschange_after) {
-					if (dp->setpoint)
+					if (dp->setpoint) {
 						snprintf(temp, sz_temp, translate("gettextFromC", "Stay at %.*f %s for %d:%02d min - runtime %d:%02u on %s (SP = %.1fbar)"),
-								decimals, depthvalue, depth_unit,
-								FRACTION(dp->time - lasttime, 60),
-								FRACTION(dp->time, 60),
-								gasname(&gasmix),
-								(double) dp->setpoint / 1000.0);
-					else
+							decimals, depthvalue, depth_unit,
+							FRACTION(dp->time - lasttime, 60),
+							FRACTION(dp->time, 60),
+							gasname(&gasmix),
+							(double) dp->setpoint / 1000.0);
+					} else {
 						snprintf(temp, sz_temp, translate("gettextFromC", "Stay at %.*f %s for %d:%02d min - runtime %d:%02u on %s"),
-								decimals, depthvalue, depth_unit,
-								FRACTION(dp->time - lasttime, 60),
-								FRACTION(dp->time, 60),
-								gasname(&gasmix));
-
+							decimals, depthvalue, depth_unit,
+							FRACTION(dp->time - lasttime, 60),
+							FRACTION(dp->time, 60),
+							gasname(&gasmix));
+					}
 					len += snprintf(buffer + len, sz_buffer - len, "%s<br>", temp);
 					newdepth = dp->depth.mm;
 					lasttime = dp->time;
@@ -271,22 +313,40 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 				if ((isascent || dp->entered) && gaschange_after && dp->next && nextdp && (dp->depth.mm != nextdp->depth.mm || nextdp->entered)) {
 					if (dp->setpoint) {
 						snprintf(temp, sz_temp, translate("gettextFromC", "(SP = %.1fbar)"), (double) nextdp->setpoint / 1000.0);
-						len += snprintf(buffer + len, sz_buffer - len, "<td style='padding-left: 10px; color: red; float: left;'><b>%s %s</b></td>", gasname(&newgasmix),
-									temp);
+						len += snprintf(buffer + len, sz_buffer - len, "<td style='padding-left: 10px; color: red; float: left;'><b>%s %s</b></td>",
+							gasname(&newgasmix), temp);
 					} else {
-							len += snprintf(buffer + len, sz_buffer - len, "<td style='padding-left: 10px; color: red; float: left;'><b>%s</b></td>", gasname(&newgasmix));
+						len += snprintf(buffer + len, sz_buffer - len, "<td style='padding-left: 10px; color: red; float: left;'><b>%s</b></td>",
+							gasname(&newgasmix));
+						if (isascent && (get_he(&lastprintgasmix) > 0)) { // For a trimix gas change on ascent, save ICD info if previous cylinder had helium
+							if (isobaric_counterdiffusion(&lastprintgasmix, &newgasmix, &icdvalues)) // Do icd calulations
+								icdwarning = true;
+							if (icdvalues.dN2 > 0) { // If the gas change involved helium as well as an increase in nitrogen..
+								icdlen += add_icd_entry(icdbuffer+icdlen, sz_icdbuf-icdlen, &icdvalues, icdtableheader, dp->time, depth_to_mbar(dp->depth.mm, dive), &lastprintgasmix, &newgasmix); // .. then print calculations to buffer.
+								icdtableheader = false;
+							}
+						}
 					}
 					lastprintsetpoint = nextdp->setpoint;
 					lastprintgasmix = newgasmix;
 					gaschange_after = false;
 				} else if (gaschange_before) {
-				// If a new gas has been used for this segment, now is the time to show it
+					// If a new gas has been used for this segment, now is the time to show it
 					if (dp->setpoint) {
 						snprintf(temp, sz_temp, translate("gettextFromC", "(SP = %.1fbar)"), (double) dp->setpoint / 1000.0);
-						len += snprintf(buffer + len, sz_buffer - len, "<td style='padding-left: 10px; color: red; float: left;'><b>%s %s</b></td>", gasname(&gasmix),
-									temp);
+						len += snprintf(buffer + len, sz_buffer - len, "<td style='padding-left: 10px; color: red; float: left;'><b>%s %s</b></td>",
+							gasname(&gasmix), temp);
 					} else {
-							len += snprintf(buffer + len, sz_buffer - len, "<td style='padding-left: 10px; color: red; float: left;'><b>%s</b></td>", gasname(&gasmix));
+						len += snprintf(buffer + len, sz_buffer - len, "<td style='padding-left: 10px; color: red; float: left;'><b>%s</b></td>",
+							gasname(&gasmix));
+						if (get_he(&lastprintgasmix) > 0) {  // For a trimix gas change, save ICD info if previous cylinder had helium
+							if (isobaric_counterdiffusion(&lastprintgasmix, &gasmix, &icdvalues))  // Do icd calculations
+								icdwarning = true;
+							if (icdvalues.dN2 > 0) { // If the gas change involved helium as well as an increase in nitrogen..
+								icdlen += add_icd_entry(icdbuffer+icdlen, sz_icdbuf-icdlen, &icdvalues, icdtableheader, lasttime, depth_to_mbar(dp->depth.mm, dive), &lastprintgasmix, &gasmix); // .. then print data to buffer.
+								icdtableheader = false;
+							}
+						} 
 					}
 					// Set variables so subsequent iterations can test against the last gas printed
 					lastprintsetpoint = dp->setpoint;
@@ -301,18 +361,27 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 			}
 		}
 		if (gaschange_after) {
-			// gas switch at this waypoint
+			// gas switch at this waypoint for verbatim
 			if (plan_verbatim) {
 				if (lastsetpoint >= 0) {
-					if (nextdp && nextdp->setpoint)
+					if (nextdp && nextdp->setpoint) {
 						snprintf(temp, sz_temp, translate("gettextFromC", "Switch gas to %s (SP = %.1fbar)"), gasname(&newgasmix), (double) nextdp->setpoint / 1000.0);
-					else
+					} else {
 						snprintf(temp, sz_temp, translate("gettextFromC", "Switch gas to %s"), gasname(&newgasmix));
-
+						if ((isascent) && (get_he(&lastprintgasmix) > 0)) {          // For a trimix gas change on ascent:
+							if (isobaric_counterdiffusion(&lastprintgasmix, &newgasmix, &icdvalues)) // Do icd calculations
+								icdwarning = true;
+							if (icdvalues.dN2 > 0) { // If the gas change involved helium as well as an increase in nitrogen..
+								icdlen += add_icd_entry(icdbuffer+icdlen, sz_icdbuf-icdlen, &icdvalues, icdtableheader, dp->time, depth_to_mbar(dp->depth.mm, dive), &lastprintgasmix, &newgasmix); // ... then print data to buffer.
+								icdtableheader = false;
+							}
+						}
+					}
 					len += snprintf(buffer + len, sz_buffer - len, "%s<br>", temp);
 				}
+				lastprintgasmix = newgasmix;
 				gaschange_after = false;
-			gasmix = newgasmix;
+				gasmix = newgasmix;
 			}
 		}
 		lastprintdepth = newdepth;
@@ -343,8 +412,8 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 		else
 			temp_len = snprintf(temp, sz_temp, translate("gettextFromC", "Deco model: VPM-B at +%d conservatism"), diveplan->vpmb_conservatism);
 		if (diveplan->eff_gflow)
-			temp_len += snprintf(temp + temp_len, sz_temp - temp_len,  translate("gettextFromC", ", effective GF=%d/%d"), diveplan->eff_gflow
-					     , diveplan->eff_gfhigh);
+			temp_len += snprintf(temp + temp_len, sz_temp - temp_len,  translate("gettextFromC", ", effective GF=%d/%d"), diveplan->eff_gflow,
+				diveplan->eff_gfhigh);
 
 	} else if (decoMode() == RECREATIONAL){
 		snprintf(temp, sz_temp, translate("gettextFromC", "Deco model: Recreational mode based on Bühlmann ZHL-16B with GFLow = %d%% and GFHigh = %d%%"),
@@ -356,9 +425,7 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 	int altitude = (int) get_depth_units((int) (log(1013.0 / diveplan->surface_pressure) * 7800000), NULL, &depth_unit);
 
 	len += snprintf(buffer + len, sz_buffer - len, translate("gettextFromC", "ATM pressure: %dmbar (%d%s)<br></div>"),
-			diveplan->surface_pressure,
-			altitude,
-			depth_unit);
+		diveplan->surface_pressure, altitude, depth_unit);
 
 	/* Get SAC values and units for printing it in gas consumption */
 	double bottomsacvalue, decosacvalue;
@@ -393,8 +460,8 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 		deco_volume = get_volume_units(cyl->deco_gas_used.mliter, NULL, &unit);
 		if (cyl->type.size.mliter) {
 			int remaining_gas = lrint((double)cyl->end.mbar * cyl->type.size.mliter / 1000.0 / gas_compressibility_factor(&cyl->gasmix, cyl->end.mbar / 1000.0));
-			double deco_pressure_mbar = isothermal_pressure(&cyl->gasmix, 1.0, remaining_gas + cyl->deco_gas_used.mliter, cyl->type.size.mliter) * 1000
-					- cyl->end.mbar;
+			double deco_pressure_mbar = isothermal_pressure(&cyl->gasmix, 1.0, remaining_gas + cyl->deco_gas_used.mliter,
+				cyl->type.size.mliter) * 1000 - cyl->end.mbar;
 			deco_pressure = get_pressure_units(lrint(deco_pressure_mbar), &pressure_unit);
 			pressure = get_pressure_units(cyl->start.mbar - cyl->end.mbar, &pressure_unit);
 			/* Warn if the plan uses more gas than is available in a cylinder
@@ -431,8 +498,8 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 					mingas_depth = get_depth_units(lastbottomdp->depth.mm, NULL, &depth_unit);
 					/* Print it to results */
 					if (cyl->start.mbar > lastbottomdp->minimum_gas.mbar) {
-						snprintf(mingas, sizeof(mingas), "<br>&nbsp;&mdash; <span style='color: %s;'>%s</span> (%s %.1fx%s/+%d%s@%.0f%s): \
-							%.0f%s/%.0f%s<span style='color: %s;'>/&Delta;:%+.0f%s</span>",
+						snprintf(mingas, sizeof(mingas), "<br>&nbsp;&mdash; <span style='color: %s;'>%s</span> (%s %.1fx%s/+%d%s@%.0f%s): "
+							"%.0f%s/%.0f%s<span style='color: %s;'>/&Delta;:%+.0f%s</span>",
 							mingas_d_pressure > 0 ? "green" :"red",
 							translate("gettextFromC", "Minimum gas"),
 							translate("gettextFromC", "based on"),
@@ -452,21 +519,36 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 					}
 				}
 			/* Print the gas consumption for every cylinder here to temp buffer. */
-			if (lrint(volume) > 0)
-				snprintf(temp, sz_temp, translate("gettextFromC", "%.0f%s/%.0f%s of <span style='color: red;'><b>%s</b></span> (%.0f%s/%.0f%s in planned ascent)"), volume, unit, pressure, pressure_unit, gasname(&cyl->gasmix), deco_volume, unit, deco_pressure, pressure_unit);
-			else
-				snprintf(temp, sz_temp, translate("gettextFromC", "%.0f%s/%.0f%s of <span style='color: red;'><b>%s</b></span>"), volume, unit, pressure, pressure_unit, gasname(&cyl->gasmix));
-
+			if (lrint(volume) > 0) {
+				snprintf(temp, sz_temp, translate("gettextFromC", "%.0f%s/%.0f%s of <span style='color: red;'><b>%s</b></span> (%.0f%s/%.0f%s in planned ascent)"),
+					volume, unit, pressure, pressure_unit, gasname(&cyl->gasmix), deco_volume, unit, deco_pressure, pressure_unit);
+			} else {
+				snprintf(temp, sz_temp, translate("gettextFromC", "%.0f%s/%.0f%s of <span style='color: red;'><b>%s</b></span>"),
+					volume, unit, pressure, pressure_unit, gasname(&cyl->gasmix));
+			}
 		} else {
-			if (lrint(volume) > 0)
+			if (lrint(volume) > 0) {
 				snprintf(temp, sz_temp, translate("gettextFromC", "%.0f%s of <span style='color: red;'><b>%s</b></span> (%.0f%s during planned ascent)"),
 					volume, unit, gasname(&cyl->gasmix), deco_volume, unit);
-			else
+			} else {
 				snprintf(temp, sz_temp, translate("gettextFromC", "%.0f%s of <span style='color: red;'><b>%s</b></span>"),
 					volume, unit, gasname(&cyl->gasmix));
+			}
 		}
 		/* Gas consumption: Now finally print all strings to output */
-		len += snprintf(buffer + len, sz_buffer - len, "%s%s%s<br>", temp, warning, mingas);
+		len += snprintf(buffer + len, sz_buffer - len, "%s%s%s<br></div>", temp, warning, mingas);
+	}
+
+	/* For trimix OC dives, if an icd table header and icd data were printed to buffer, then add the ICD table here */
+	if (!icdtableheader) {
+		icdlen += snprintf(icdbuffer + icdlen, sz_icdbuf - icdlen,"</tbody></table>"); // End the ICD table
+		len += snprintf(buffer + len, sz_buffer - len, "%s", icdbuffer); // ..and add it to the html buffer
+		if (icdwarning) { // If necessary, add warning
+			len += snprintf(buffer + len, sz_buffer - len, "<span style='color: red;'>%s</span> %s",
+				translate("gettextFromC", "Warning:"),
+				translate("gettextFromC", "Isobaric counterdiffusion conditions exceeded"));
+		}
+		len += snprintf(buffer + len, sz_buffer - len, "<br></div>");
 	}
 
 	/* Print warnings for pO2 */
@@ -484,7 +566,8 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 					int decimals;
 					double depth_value = get_depth_units(dp->depth.mm, &decimals, &depth_unit);
 					len = strlen(buffer);
-					if (!o2warning_exist) len += snprintf(buffer + len, sz_buffer - len, "<br>");
+					if (!o2warning_exist)
+						len += snprintf(buffer + len, sz_buffer - len, "<div>");
 					o2warning_exist = true;
 					snprintf(temp, sz_temp,
 						 translate("gettextFromC", "high pO₂ value %.2f at %d:%02u with gas %s at depth %.*f %s"),
@@ -496,7 +579,8 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 					int decimals;
 					double depth_value = get_depth_units(dp->depth.mm, &decimals, &depth_unit);
 					len = strlen(buffer);
-					if (!o2warning_exist) len += snprintf(buffer + len, sz_buffer - len, "<br>");
+					if (!o2warning_exist)
+						len += snprintf(buffer + len, sz_buffer - len, "<div>");
 					o2warning_exist = true;
 					snprintf(temp, sz_temp,
 						 translate("gettextFromC", "low pO₂ value %.2f at %d:%02u with gas %s at depth %.*f %s"),
@@ -512,6 +596,9 @@ void add_plan_to_notes(struct diveplan *diveplan, struct dive *dive, bool show_d
 	snprintf(buffer + len, sz_buffer - len, "</div>");
 	dive->notes = strdup(buffer);
 
+finished:
 	free((void *)buffer);
 	free((void *)temp);
+	free((void *)icdbuffer);
+
 }
