@@ -395,6 +395,8 @@ static void save_events(struct membuffer *b, struct dive *dive, struct event *ev
 static void save_dc(struct membuffer *b, struct dive *dive, struct divecomputer *dc)
 {
 	show_utf8(b, "model ", dc->model, "\n");
+	if (dc->last_manual_time.seconds)
+		put_duration(b, dc->last_manual_time, "lastmanualtime ", "min\n");
 	if (dc->deviceid)
 		put_format(b, "deviceid %08x\n", dc->deviceid);
 	if (dc->diveid)
@@ -901,6 +903,7 @@ static void save_divesites(git_repository *repo, struct dir *tree)
 	struct membuffer dirname = { 0 };
 	put_format(&dirname, "01-Divesites");
 	subdir = new_directory(repo, tree, &dirname);
+	free_buffer(&dirname);
 
 	for (int i = 0; i < dive_site_table.nr; i++) {
 		struct membuffer b = { 0 };
@@ -944,6 +947,7 @@ static void save_divesites(git_repository *repo, struct dir *tree)
 			}
 		}
 		blob_insert(repo, subdir, &b, mb_cstring(&site_file_name));
+		free_buffer(&site_file_name);
 	}
 }
 
@@ -1088,11 +1092,11 @@ static void create_commit_message(struct membuffer *msg, bool create_empty)
 			nr = dive->number;
 
 		put_format(msg, "dive %d: %s", nr, location);
-		if (trip && trip->location && *trip->location && strcmp(trip->location, location))
+		if (trip && !empty_string(trip->location) && strcmp(trip->location, location))
 			put_format(msg, " (%s)", trip->location);
 		put_format(msg, "\n");
 		do {
-			if (dc->model && *dc->model) {
+			if (!empty_string(dc->model)) {
 				put_format(msg, "%s%s", sep, dc->model);
 				sep = ", ";
 			}
@@ -1272,12 +1276,9 @@ int do_git_save(git_repository *repo, const char *branch, const char *remote, bo
 	if (create_new_commit(repo, remote, branch, &id, create_empty))
 		return report_error("creating commit failed");
 
-	if (remote && prefs.cloud_background_sync && !prefs.git_local_only) {
-		/* now sync the tree with the cloud server */
-		if (strstr(remote, prefs.cloud_git_url)) {
-			return sync_with_remote(repo, remote, branch, RT_HTTPS);
-		}
-	}
+	/* now sync the tree with the remote server */
+	if (remote && !prefs.git_local_only)
+		return sync_with_remote(repo, remote, branch, url_to_remote_transport(remote));
 	return 0;
 }
 
