@@ -410,73 +410,3 @@ QString DiveObjectHelper::firstGas() const
 	gas = get_gas_string(m_dive->cylinder[0].gasmix);
 	return gas;
 }
-
-QStringList DiveObjectHelper::suitList() const
-{
-	QStringList suits;
-	struct dive *d;
-	int i = 0;
-	for_each_dive (i, d) {
-		QString temp = d->suit;
-		if (!temp.isEmpty())
-			suits << d->suit;
-	}
-	suits.removeDuplicates();
-	suits.sort();
-	return suits;
-}
-
-QStringList DiveObjectHelper::locationList() const
-{
-	QStringList locations;
-	struct dive *d;
-	struct dive_site *ds;
-	int i = 0;
-	for_each_dive (i, d) {
-		if ((ds = get_dive_site_by_uuid(d->dive_site_uuid)) != NULL) {
-			QString temp = ds->name;
-			if (!temp.isEmpty())
-				locations << temp;
-		}
-	}
-	locations.removeDuplicates();
-	locations.sort();
-	return locations;
-}
-
-QStringList DiveObjectHelper::buddyList() const
-{
-	QStringList buddies;
-	struct dive *d;
-	int i = 0;
-	for_each_dive (i, d) {
-		QString temp = d->buddy;
-		if (!temp.isEmpty() && !temp.contains(",")){
-			buddies << d->buddy;
-		}
-		else if (!temp.isEmpty()){
-			QRegExp sep("(,\\s)");
-			QStringList tempList = temp.split(sep);
-			buddies << tempList;
-			buddies << tr("Multiple Buddies");
-		}
-	}
-	buddies.removeDuplicates();
-	buddies.sort();
-	return buddies;
-}
-
-QStringList DiveObjectHelper::divemasterList() const
-{
-	QStringList divemasters;
-	struct dive *d;
-	int i = 0;
-	for_each_dive (i, d) {
-		QString temp = d->divemaster;
-		if (!temp.isEmpty())
-			divemasters << d->divemaster;
-	}
-	divemasters.removeDuplicates();
-	divemasters.sort();
-	return divemasters;
-}
