@@ -47,10 +47,6 @@ class DiveObjectHelper : public QObject {
 	Q_PROPERTY(QString startPressure READ startPressure CONSTANT)
 	Q_PROPERTY(QString endPressure READ endPressure CONSTANT)
 	Q_PROPERTY(QString firstGas READ firstGas CONSTANT)
-	Q_PROPERTY(QStringList suitList READ suitList CONSTANT)
-	Q_PROPERTY(QStringList buddyList READ buddyList CONSTANT)
-	Q_PROPERTY(QStringList divemasterList READ divemasterList CONSTANT)
-	Q_PROPERTY(QStringList locationList READ locationList CONSTANT)
 public:
 	DiveObjectHelper(struct dive *dive = NULL);
 	~DiveObjectHelper();
@@ -93,10 +89,6 @@ public:
 	QString startPressure() const;
 	QString endPressure() const;
 	QString firstGas() const;
-	QStringList suitList() const;
-	QStringList locationList() const;
-	QStringList buddyList() const;
-	QStringList divemasterList() const;
 
 private:
 	struct dive *m_dive;
