@@ -331,7 +331,6 @@ class CloudStorageSettings : public QObject {
 	Q_PROPERTY(bool git_local_only       READ gitLocalOnly       WRITE setGitLocalOnly       NOTIFY gitLocalOnlyChanged)
 	Q_PROPERTY(bool save_password_local  READ savePasswordLocal  WRITE setSavePasswordLocal  NOTIFY savePasswordLocalChanged)
 	Q_PROPERTY(short verification_status READ verificationStatus WRITE setVerificationStatus NOTIFY verificationStatusChanged)
-	Q_PROPERTY(bool background_sync      READ backgroundSync     WRITE setBackgroundSync     NOTIFY backgroundSyncChanged)
 public:
 	CloudStorageSettings(QObject *parent);
 	QString password() const;
@@ -343,7 +342,6 @@ public:
 	QString gitUrl() const;
 	bool savePasswordLocal() const;
 	short verificationStatus() const;
-	bool backgroundSync() const;
 	bool gitLocalOnly() const;
 	bool saveUserIdLocal() const;
 
@@ -357,7 +355,6 @@ public slots:
 	void setGitUrl(const QString& value);
 	void setSavePasswordLocal(bool value);
 	void setVerificationStatus(short value);
-	void setBackgroundSync(bool value);
 	void setGitLocalOnly(bool value);
 	void setSaveUserIdLocal(bool value);
 
@@ -371,7 +368,6 @@ signals:
 	void gitUrlChanged(const QString& value);
 	void savePasswordLocalChanged(bool value);
 	void verificationStatusChanged(short value);
-	void backgroundSyncChanged(bool value);
 	void gitLocalOnlyChanged(bool value);
 	void saveUserIdLocalChanged(bool value);
 
