@@ -152,7 +152,7 @@ void BtDeviceSelectionDialog::on_save_clicked()
 	QBluetoothDeviceInfo remoteDeviceInfo = currentItem->data(Qt::UserRole).value<QBluetoothDeviceInfo>();
 
 	// Save the selected device
-	selectedRemoteDeviceInfo = QSharedPointer<QBluetoothDeviceInfo>(new QBluetoothDeviceInfo(remoteDeviceInfo));
+	selectedRemoteDeviceInfo.reset(new QBluetoothDeviceInfo(remoteDeviceInfo));
 	QString address = remoteDeviceInfo.address().isNull() ? remoteDeviceInfo.deviceUuid().toString() :
 								remoteDeviceInfo.address().toString();
 	saveBtDeviceInfo(address.toUtf8().constData(), remoteDeviceInfo);
@@ -449,24 +449,49 @@ void BtDeviceSelectionDialog::deviceDiscoveryError(QBluetoothDeviceDiscoveryAgen
 }
 
 extern QString markBLEAddress(const QBluetoothDeviceInfo *device);
+extern QString btDeviceAddress(const QBluetoothDeviceInfo *device, bool isBle);
 
 QString BtDeviceSelectionDialog::getSelectedDeviceAddress()
 {
-	if (selectedRemoteDeviceInfo)
-		return markBLEAddress(selectedRemoteDeviceInfo.data());
+	if (!selectedRemoteDeviceInfo)
+		return QString();
 
-	return QString();
+	int btMode = ui->btMode->currentIndex();
+	QBluetoothDeviceInfo *device = selectedRemoteDeviceInfo.data();
+
+	switch (btMode) {
+	case 0:		// Auto
+	default:
+		return markBLEAddress(device);
+	case 1:		// Force LE
+		return btDeviceAddress(device, true);
+	case 2:		// Force classical
+		return btDeviceAddress(device, false);
+	}
 }
 
 QString BtDeviceSelectionDialog::getSelectedDeviceName()
 {
-	if (selectedRemoteDeviceInfo) {
+	if (selectedRemoteDeviceInfo)
 		return selectedRemoteDeviceInfo.data()->name();
-	}
 
 	return QString();
 }
 
+QString BtDeviceSelectionDialog::getSelectedDeviceText()
+{
+	return formatDeviceText(getSelectedDeviceAddress(), getSelectedDeviceName());
+}
+
+QString BtDeviceSelectionDialog::formatDeviceText(const QString &address, const QString &name)
+{
+	if (address.isEmpty())
+		return name;
+	if (name.isEmpty())
+		return address;
+	return QString("%1 (%2)").arg(name, address);
+}
+
 void BtDeviceSelectionDialog::updateLocalDeviceInformation()
 {
 #if defined(Q_OS_WIN)
