@@ -14,13 +14,6 @@
 #include <QMessageBox>
 #include <QShortcut>
 
-namespace DownloadFromDcGlobal {
-	const char *err_string;
-};
-
-// Workaround abuse of old libdc types
-#define DC_TRANSPORT_BLUETOOTH 1024
-
 DownloadFromDCWidget::DownloadFromDCWidget(QWidget *parent, Qt::WindowFlags f) : QDialog(parent, f),
 	downloading(false),
 	previousLast(0),
@@ -112,13 +105,13 @@ void DownloadFromDCWidget::updateProgressBar()
 {
 	static char *last_text = NULL;
 
-	if (same_string(last_text, "")) {
+	if (empty_string(last_text)) {
 		// if we get the first actual text after the download is finished
 		// (which happens for example on the OSTC), then don't bother
-		if (!same_string(progress_bar_text, "") && IS_FP_SAME(progress_bar_fraction, 1.0))
+		if (!empty_string(progress_bar_text) && IS_FP_SAME(progress_bar_fraction, 1.0))
 			progress_bar_text = "";
 	}
-	if (!same_string(progress_bar_text , "")) {
+	if (!empty_string(progress_bar_text)) {
 		ui.progressBar->setFormat(progress_bar_text);
 #if defined(Q_OS_MAC)
 		// on mac the progress bar doesn't show its text
@@ -222,9 +215,6 @@ void DownloadFromDCWidget::updateState(states state)
 	else if (state == ERROR) {
 		timer->stop();
 
-		// Show messages that worker thread produced.
-		MainWindow::instance()->showErrors();
-
 		QMessageBox::critical(this, TITLE_OR_TEXT(tr("Error"), thread.error), QMessageBox::Ok);
 		markChildrenAsEnabled();
 		progress_bar_text = "";
@@ -292,10 +282,16 @@ void DownloadFromDCWidget::on_downloadCancelRetryButton_clicked()
 	data->setProduct(ui.product->currentText());
 #if defined(BT_SUPPORT)
 	data->setBluetoothMode(ui.bluetoothMode->isChecked());
-	if (data->bluetoothMode() && btDeviceSelectionDialog != NULL) {
-		// Get the selected device address
-		data->setDevName(btDeviceSelectionDialog->getSelectedDeviceAddress());
-		data->setDevBluetoothName(btDeviceSelectionDialog->getSelectedDeviceName());
+	if (data->bluetoothMode()) {
+		// Get the selected device address from dialog or from preferences
+		if (btDeviceSelectionDialog != NULL) {
+			data->setDevName(btDeviceSelectionDialog->getSelectedDeviceAddress());
+			data->setDevBluetoothName(btDeviceSelectionDialog->getSelectedDeviceName());
+		} else {
+			auto dc = SettingsObjectWrapper::instance()->dive_computer_settings;
+			data->setDevName(dc->dc_device());
+			data->setDevBluetoothName(dc->dc_device_name());
+		}
 	} else
 		// this breaks an "else if" across lines... not happy...
 #endif
