@@ -88,10 +88,6 @@ public:
 	void enableDisableCloudActions();
 	void setCheckedActionFilterTags(bool checked);
 
-	// Shows errors that have accumulated.
-	// Must be called from GUI thread.
-	void showErrors();
-
 private
 slots:
 	/* file menu action */
@@ -103,7 +99,7 @@ slots:
 	void on_actionClose_triggered();
 	void on_actionCloudstorageopen_triggered();
 	void on_actionCloudstoragesave_triggered();
-	void on_actionTake_cloud_storage_online_triggered();
+	void on_actionCloudOnline_triggered();
 	void on_actionPrint_triggered();
 	void on_actionPreferences_triggered();
 	void on_actionQuit_triggered();
@@ -159,6 +155,7 @@ protected:
 
 signals:
 	void startDiveSiteEdit();
+	void showError(QString message);
 
 public
 slots:
@@ -198,6 +195,8 @@ private:
 	bool askSaveChanges();
 	bool okToClose(QString message);
 	void closeCurrentFile();
+	void setCurrentFile(const char *f);
+	void updateCloudOnlineStatus();
 	void showProgressBar();
 	void hideProgressBar();
 	void writeSettings();
@@ -205,6 +204,7 @@ private:
 	int file_save_as();
 	void beginChangeState(CurrentState s);
 	void saveSplitterSizes();
+	void toggleCollapsible(bool toggle);
 	QString lastUsedDir();
 	void updateLastUsedDir(const QString &s);
 	void registerApplicationState(const QByteArray& state, QWidget *topLeft, QWidget *topRight, QWidget *bottomLeft, QWidget *bottomRight);
