@@ -393,7 +393,7 @@ void MainTab::updateDepthDuration()
 	ui.depthLabel->setVisible(true);
 	ui.duration->setVisible(true);
 	ui.durationLabel->setVisible(true);
-	ui.duration->setText(QDateTime::fromTime_t(displayed_dive.duration.seconds).toUTC().toString("h:mm"));
+	ui.duration->setText(render_seconds_to_string(displayed_dive.duration.seconds));
 	ui.depth->setText(get_depth_string(displayed_dive.maxdepth, true));
 }
 
@@ -579,13 +579,12 @@ void MainTab::updateDiveInfo(bool clear)
 				ui.durationLabel->setVisible(isManual);
 			}
 		}
-		ui.duration->setText(QDateTime::fromTime_t(displayed_dive.duration.seconds).toUTC().toString("h:mm"));
+		ui.duration->setText(render_seconds_to_string(displayed_dive.duration.seconds));
 		ui.depth->setText(get_depth_string(displayed_dive.maxdepth, true));
 		ui.DiveType->setCurrentIndex(get_dive_dc(&displayed_dive, dc_number)->divemode);
 
 		volume_t gases[MAX_CYLINDERS] = {};
 		get_gas_used(&displayed_dive, gases);
-		QString volumes;
 		int mean[MAX_CYLINDERS], duration[MAX_CYLINDERS];
 		per_cylinder_mean_depth(&displayed_dive, select_dc(&displayed_dive), mean, duration);
 
@@ -629,6 +628,7 @@ void MainTab::updateDiveInfo(bool clear)
 		ui.timeEdit->setSpecialValueText(QString("-"));
 		ui.timeEdit->setMinimumTime(QTime(0, 0, 0, 0));
 		ui.timeEdit->setTime(QTime(0, 0, 0, 0));
+		ui.tagWidget->clear();
 	}
 	editMode = rememberEM;
 	ui.cylinders->view()->hideColumn(CylindersModel::DEPTH);
