@@ -17,6 +17,7 @@
 
 #include "qt-models/divelistmodel.h"
 #include "qt-models/gpslistmodel.h"
+#include "qt-models/completionmodels.h"
 #include "core/divelist.h"
 #include "core/device.h"
 #include "core/pref.h"
@@ -36,6 +37,15 @@ QMLManager *QMLManager::m_instance = NULL;
 
 #define NOCLOUD_LOCALSTORAGE format_string("%s/cloudstorage/localrepo[master]", system_default_directory())
 
+extern "C" void showErrorFromC(char *buf)
+{
+	QString error(buf);
+	free(buf);
+	// By using invokeMethod with Qt:AutoConnection, the error string is safely
+	// transported across thread boundaries, if not called from the UI thread.
+	QMetaObject::invokeMethod(QMLManager::instance(), "registerError", Qt::AutoConnection, Q_ARG(QString, error));
+}
+
 static void progressCallback(const char *text)
 {
 	QMLManager *self = QMLManager::instance();
@@ -79,6 +89,21 @@ extern "C" int gitProgressCB(const char *text)
 	return 0;
 }
 
+void QMLManager::registerError(const QString &error)
+{
+	appendTextToLog(error);
+	if (!m_lastError.isEmpty())
+		m_lastError += '\n';
+	m_lastError += error;
+}
+
+QString QMLManager::consumeError()
+{
+	QString ret;
+	ret.swap(m_lastError);
+	return ret;
+}
+
 void QMLManager::btHostModeChange(QBluetoothLocalDevice::HostMode state)
 {
 	BTDiscovery *btDiscovery = BTDiscovery::instance();
@@ -115,6 +140,7 @@ QMLManager::QMLManager() : m_locationServiceEnabled(false),
 {
 	m_instance = this;
 	m_lastDevicePixelRatio = qApp->devicePixelRatio();
+	timer.start();
 	connect(qobject_cast<QApplication *>(QApplication::instance()), &QApplication::applicationStateChanged, this, &QMLManager::applicationStateChanged);
 
 	QString libdcLogFileName = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + "/libdivecomputer.log";
@@ -132,6 +158,7 @@ QMLManager::QMLManager() : m_locationServiceEnabled(false),
 				+ " at " + QDateTime::currentDateTime().toString());
 	}
 #endif
+	set_error_cb(&showErrorFromC);
 	appendTextToLog("Starting " + getUserAgent());
 	appendTextToLog(QStringLiteral("built with libdivecomputer v%1").arg(dc_version(NULL)));
 	appendTextToLog(QStringLiteral("built with Qt Version %1, runtime from Qt Version %2").arg(QT_VERSION_STR).arg(qVersion()));
@@ -160,8 +187,6 @@ QMLManager::QMLManager() : m_locationServiceEnabled(false),
 
 void QMLManager::applicationStateChanged(Qt::ApplicationState state)
 {
-	if (!timer.isValid())
-		timer.start();
 	QString stateText;
 	switch (state) {
 	case Qt::ApplicationActive: stateText = "active"; break;
@@ -182,7 +207,7 @@ void QMLManager::applicationStateChanged(Qt::ApplicationState state)
 		//       make sure the user sees that we are saving data if they come back
 		//       while this is running
 		saveChangesCloud(false);
-		appendTextToLog(QString::number(timer.elapsed() / 1000.0,'f', 3) + ": done saving to git local / remote");
+		appendTextToLog("done saving to git local / remote");
 	}
 }
 
@@ -208,11 +233,11 @@ void QMLManager::openLocalThenRemote(QString url)
 		 *    no cloud repo solves this.
 		 */
 
-		if (credentialStatus() != CS_NOCLOUD)
+		if (m_credentialStatus != CS_NOCLOUD)
 			setCredentialStatus(CS_NEED_TO_VERIFY);
 	} else {
 		// if we can load from the cache, we know that we have a valid cloud account
-		if (credentialStatus() == CS_UNKNOWN)
+		if (m_credentialStatus == CS_UNKNOWN)
 			setCredentialStatus(CS_VERIFIED);
 		prefs.unit_system = git_prefs.unit_system;
 		if (git_prefs.unit_system == IMPERIAL)
@@ -231,11 +256,11 @@ void QMLManager::openLocalThenRemote(QString url)
 		appendTextToLog(QStringLiteral("%1 dives loaded from cache").arg(dive_table.nr));
 		setNotificationText(tr("%1 dives loaded from local dive data file").arg(dive_table.nr));
 	}
-	if (credentialStatus() == CS_NEED_TO_VERIFY) {
+	if (m_credentialStatus == CS_NEED_TO_VERIFY) {
 		appendTextToLog(QStringLiteral("have cloud credentials, but still needs PIN"));
 		setShowPin(true);
 	}
-	if (oldStatus() == CS_NOCLOUD) {
+	if (m_oldStatus == CS_NOCLOUD) {
 		// if we switch to credentials from CS_NOCLOUD, we take things online temporarily
 		prefs.git_local_only = false;
 		appendTextToLog(QStringLiteral("taking things online to be able to switch to cloud account"));
@@ -248,6 +273,15 @@ void QMLManager::openLocalThenRemote(QString url)
 		appendTextToLog(QStringLiteral("have cloud credentials, trying to connect"));
 		tryRetrieveDataFromBackend();
 	}
+	updateAllGlobalLists();
+}
+
+void QMLManager::updateAllGlobalLists()
+{
+	buddyModel.updateModel(); emit buddyListChanged();
+	suitModel.updateModel(); emit suitListChanged();
+	divemasterModel.updateModel(); emit divemasterListChanged();
+	locationModel.update(); emit locationListChanged();
 }
 
 void QMLManager::mergeLocalRepo()
@@ -284,9 +318,9 @@ void QMLManager::cancelCredentialsPinSetup()
 
 	setCredentialStatus(CS_UNKNOWN);
 	s.beginGroup("CloudStorage");
-	s.setValue("email", cloudUserName());
-	s.setValue("password", cloudPassword());
-	s.setValue("cloud_verification_status", credentialStatus());
+	s.setValue("email", m_cloudUserName);
+	s.setValue("password", m_cloudPassword);
+	s.setValue("cloud_verification_status", m_credentialStatus);
 	s.sync();
 	setStartPageText(tr("Starting..."));
 
@@ -302,21 +336,20 @@ void QMLManager::finishSetup()
 	setCredentialStatus((cloud_status_qml) prefs.cloud_verification_status);
 	// if the cloud credentials are valid, we should get the GPS Webservice ID as well
 	QString url;
-	if (!cloudUserName().isEmpty() &&
-	    !cloudPassword().isEmpty() &&
+	if (!m_cloudUserName.isEmpty() &&
+	    !m_cloudPassword.isEmpty() &&
 	    getCloudURL(url) == 0) {
 		// we know that we are the first ones to access git storage, so we don't need to test,
 		// but we need to make sure we stay the only ones accessing git storage
 		alreadySaving = true;
 		openLocalThenRemote(url);
-	} else if (!same_string(existing_filename, "") && credentialStatus() != CS_UNKNOWN) {
+	} else if (!empty_string(existing_filename) && m_credentialStatus != CS_UNKNOWN) {
 		setCredentialStatus(CS_NOCLOUD);
 		saveCloudCredentials();
 		appendTextToLog(tr("working in no-cloud mode"));
 		int error = parse_file(existing_filename);
 		if (error) {
 			// we got an error loading the local file
-			appendTextToLog(QString("got error %2 when parsing file %1").arg(existing_filename, get_error_string()));
 			setNotificationText(tr("Error parsing local storage, giving up"));
 			set_filename(NULL);
 		} else {
@@ -350,8 +383,8 @@ QMLManager *QMLManager::instance()
 void QMLManager::savePreferences()
 {
 	auto location = SettingsObjectWrapper::instance()->location_settings;
-	location->setTimeThreshold(timeThreshold() * 60);
-	location->setDistanceThreshold(distanceThreshold());
+	location->setTimeThreshold(m_timeThreshold * 60);
+	location->setDistanceThreshold(m_distanceThreshold);
 }
 
 #define CLOUDURL QString(prefs.cloud_base_url)
@@ -363,44 +396,42 @@ void QMLManager::saveCloudCredentials()
 	bool cloudCredentialsChanged = false;
 	// make sure we only have letters, numbers, and +-_. in password and email address
 	QRegularExpression regExp("^[a-zA-Z0-9@.+_-]+$");
-	QString cloudPwd = cloudPassword();
-	QString cloudUser = cloudUserName();
-	if (credentialStatus() != CS_NOCLOUD) {
+	if (m_credentialStatus != CS_NOCLOUD) {
 		// in case of NO_CLOUD, the email address + passwd do not care, so do not check it.
-		if (cloudPwd.isEmpty() || !regExp.match(cloudPwd).hasMatch() || !regExp.match(cloudUser).hasMatch()) {
+		if (m_cloudPassword.isEmpty() || !regExp.match(m_cloudPassword).hasMatch() || !regExp.match(m_cloudUserName).hasMatch()) {
 			setStartPageText(RED_FONT + tr("Cloud storage email and password can only consist of letters, numbers, and '.', '-', '_', and '+'.") + END_FONT);
 			return;
 		}
 		// use the same simplistic regex as the backend to check email addresses
 		regExp = QRegularExpression("^[a-zA-Z0-9.+_-]+@[a-zA-Z0-9.+_-]+\\.[a-zA-Z0-9]+");
-		if (!regExp.match(cloudUser).hasMatch()) {
+		if (!regExp.match(m_cloudUserName).hasMatch()) {
 			setStartPageText(RED_FONT + tr("Invalid format for email address") + END_FONT);
 			return;
 		}
 	}
 	s.beginGroup("CloudStorage");
-	s.setValue("email", cloudUser);
-	s.setValue("password", cloudPwd);
-	s.setValue("cloud_verification_status", credentialStatus());
+	s.setValue("email", m_cloudUserName);
+	s.setValue("password", m_cloudPassword);
+	s.setValue("cloud_verification_status", m_credentialStatus);
 	s.sync();
-	if (!same_string(prefs.cloud_storage_email, qPrintable(cloudUser))) {
+	if (!same_string(prefs.cloud_storage_email, qPrintable(m_cloudUserName))) {
 		free((void *)prefs.cloud_storage_email);
-		prefs.cloud_storage_email = strdup(qPrintable(cloudUser));
+		prefs.cloud_storage_email = strdup(qPrintable(m_cloudUserName));
 		cloudCredentialsChanged = true;
 	}
 
-	cloudCredentialsChanged |= !same_string(prefs.cloud_storage_password, qPrintable(cloudPwd));
+	cloudCredentialsChanged |= !same_string(prefs.cloud_storage_password, qPrintable(m_cloudPassword));
 
-	if (credentialStatus() != CS_NOCLOUD && !cloudCredentialsChanged) {
+	if (m_credentialStatus != CS_NOCLOUD && !cloudCredentialsChanged) {
 		// just go back to the dive list
-		setCredentialStatus(oldStatus());
+		setCredentialStatus(m_oldStatus);
 	}
 
-	if (!same_string(prefs.cloud_storage_password, qPrintable(cloudPwd))) {
+	if (!same_string(prefs.cloud_storage_password, qPrintable(m_cloudPassword))) {
 		free((void *)prefs.cloud_storage_password);
-		prefs.cloud_storage_password = strdup(qPrintable(cloudPwd));
+		prefs.cloud_storage_password = strdup(qPrintable(m_cloudPassword));
 	}
-	if (cloudUser.isEmpty() || cloudPwd.isEmpty()) {
+	if (m_cloudUserName.isEmpty() || m_cloudPassword.isEmpty()) {
 		setStartPageText(RED_FONT + tr("Please enter valid cloud credentials.") + END_FONT);
 	} else if (cloudCredentialsChanged) {
 		// let's make sure there are no unsaved changes
@@ -412,7 +443,6 @@ void QMLManager::saveCloudCredentials()
 		getCloudURL(url);
 		manager()->clearAccessCache(); // remove any chached credentials
 		clear_git_id(); // invalidate our remembered GIT SHA
-		clear_dive_file_data();
 		DiveListModel::instance()->clear();
 		GpsListModel::instance()->clear();
 		setStartPageText(tr("Attempting to open cloud storage with new credentials"));
@@ -424,22 +454,22 @@ void QMLManager::saveCloudCredentials()
 		currentGitLocalOnly = prefs.git_local_only;
 		prefs.git_local_only = false;
 		openLocalThenRemote(url);
-	} else if (prefs.cloud_verification_status == CS_NEED_TO_VERIFY && !cloudPin().isEmpty()) {
+	} else if (prefs.cloud_verification_status == CS_NEED_TO_VERIFY && !m_cloudPin.isEmpty()) {
 		// the user entered a PIN?
 		tryRetrieveDataFromBackend();
 	}
 }
 
-void QMLManager::checkCredentialsAndExecute(execute_function_type execute)
+void QMLManager::tryRetrieveDataFromBackend()
 {
 	// if the cloud credentials are present, we should try to get the GPS Webservice ID
 	// and (if we haven't done so) load the dive list
-	if (!same_string(prefs.cloud_storage_email, "") &&
-	    !same_string(prefs.cloud_storage_password, "")) {
+	if (!empty_string(prefs.cloud_storage_email) &&
+	    !empty_string(prefs.cloud_storage_password)) {
 		setStartPageText(tr("Testing cloud credentials"));
 		appendTextToLog("Have credentials, let's see if they are valid");
 		CloudStorageAuthenticate *csa = new CloudStorageAuthenticate(this);
-		csa->backend(prefs.cloud_storage_email, prefs.cloud_storage_password, cloudPin());
+		csa->backend(prefs.cloud_storage_email, prefs.cloud_storage_password, m_cloudPin);
 		// let's wait here for the signal to avoid too many more nested functions
 		QTimer myTimer;
 		myTimer.setSingleShot(true);
@@ -469,7 +499,7 @@ void QMLManager::checkCredentialsAndExecute(execute_function_type execute)
 			setShowPin(true);
 			return;
 		}
-		if (showPin())
+		if (m_showPin)
 			setShowPin(false);
 
 		// now check the redirect URL to make sure everything is set up on the cloud server
@@ -481,15 +511,10 @@ void QMLManager::checkCredentialsAndExecute(execute_function_type execute)
 		reply = manager()->get(request);
 		connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(handleError(QNetworkReply::NetworkError)));
 		connect(reply, &QNetworkReply::sslErrors, this, &QMLManager::handleSslErrors);
-		connect(reply, &QNetworkReply::finished, this, execute, Qt::UniqueConnection);
+		connect(reply, &QNetworkReply::finished, this, &QMLManager::retrieveUserid, Qt::UniqueConnection);
 	}
 }
 
-void QMLManager::tryRetrieveDataFromBackend()
-{
-	checkCredentialsAndExecute(&QMLManager::retrieveUserid);
-}
-
 void QMLManager::provideAuth(QNetworkReply *reply, QAuthenticator *auth)
 {
 	if (auth->user() == QString(prefs.cloud_storage_email) &&
@@ -541,7 +566,7 @@ void QMLManager::retrieveUserid()
 	setCredentialStatus(CS_VERIFIED);
 	QString userid(prefs.userid);
 	if (userid.isEmpty()) {
-		if (same_string(prefs.cloud_storage_email, "") || same_string(prefs.cloud_storage_password, "")) {
+		if (empty_string(prefs.cloud_storage_email) || empty_string(prefs.cloud_storage_password)) {
 			appendTextToLog("cloud user name or password are empty, can't retrieve web user id");
 			revertToNoCloudIfNeeded();
 			return;
@@ -566,11 +591,9 @@ void QMLManager::retrieveUserid()
 void QMLManager::loadDivesWithValidCredentials()
 {
 	QString url;
-	timestamp_t currentDiveTimestamp = selectedDiveTimestamp();
+	timestamp_t currentDiveTimestamp = m_selectedDiveTimestamp;
 	if (getCloudURL(url)) {
-		QString errorString(get_error_string());
-		appendTextToLog(errorString);
-		setStartPageText(RED_FONT + tr("Cloud storage error: %1").arg(errorString) + END_FONT);
+		setStartPageText(RED_FONT + tr("Cloud storage error: %1").arg(consumeError()) + END_FONT);
 		revertToNoCloudIfNeeded();
 		return;
 	}
@@ -594,15 +617,12 @@ void QMLManager::loadDivesWithValidCredentials()
 	}
 	if (!error) {
 		report_error("filename is now %s", fileNamePrt.data());
-		QString errorString(get_error_string());
-		appendTextToLog(errorString);
 		set_filename(fileNamePrt.data());
 	} else {
 		report_error("failed to open file %s", fileNamePrt.data());
-		QString errorString(get_error_string());
-		appendTextToLog(errorString);
-		setNotificationText(errorString);
+		setNotificationText(consumeError());
 		revertToNoCloudIfNeeded();
+		set_filename(NULL);
 		return;
 	}
 	consumeFinishedLoad(currentDiveTimestamp);
@@ -612,7 +632,7 @@ successful_exit:
 	setLoadFromCloud(true);
 	// if we came from local storage mode, let's merge the local data into the local cache
 	// for the remote data - which then later gets merged with the remote data if necessary
-	if (oldStatus() == CS_NOCLOUD) {
+	if (m_oldStatus == CS_NOCLOUD) {
 		git_storage_update_progress(qPrintable(tr("Loading dives from local storage ('no cloud' mode)")));
 		dive_table.preexisting = dive_table.nr;
 		mergeLocalRepo();
@@ -620,9 +640,9 @@ successful_exit:
 		DiveListModel::instance()->addAllDives();
 		appendTextToLog(QStringLiteral("%1 dives loaded after importing nocloud local storage").arg(dive_table.nr));
 		saveChangesLocal();
-		if (syncToCloud() == false) {
+		if (m_syncToCloud == false) {
 			appendTextToLog(QStringLiteral("taking things back offline now that storage is synced"));
-			prefs.git_local_only = syncToCloud();
+			prefs.git_local_only = m_syncToCloud;
 		}
 	}
 	// if we got here just for an initial connection to the cloud, reset to offline
@@ -640,15 +660,15 @@ void QMLManager::revertToNoCloudIfNeeded()
 		currentGitLocalOnly = false;
 		prefs.git_local_only = true;
 	}
-	if (oldStatus() == CS_NOCLOUD) {
+	if (m_oldStatus == CS_NOCLOUD) {
 		// we tried to switch to a cloud account and had previously used local data,
 		// but connecting to the cloud account (and subsequently merging the local
 		// and cloud data) failed - so let's delete the cloud credentials and go
 		// back to CS_NOCLOUD mode in order to prevent us from losing the locally stored
 		// dives
-		if (syncToCloud() == false) {
+		if (m_syncToCloud == false) {
 			appendTextToLog(QStringLiteral("taking things back offline since sync with cloud failed"));
-			prefs.git_local_only = syncToCloud();
+			prefs.git_local_only = m_syncToCloud;
 		}
 		free((void *)prefs.cloud_storage_email);
 		prefs.cloud_storage_email = NULL;
@@ -1086,6 +1106,7 @@ void QMLManager::changesNeedSaving()
 #elif !defined(Q_OS_IOS)
 	saveChangesCloud(false);
 #endif
+	updateAllGlobalLists();
 }
 
 void QMLManager::openNoCloudRepo()
@@ -1102,8 +1123,7 @@ void QMLManager::openNoCloudRepo()
 	git = is_git_repository(filename, &branch, NULL, false);
 
 	if (git == dummy_git_repository) {
-		if (git_create_local_repo(filename))
-			appendTextToLog(get_error_string());
+		git_create_local_repo(filename);
 		set_filename(filename);
 		auto s = SettingsObjectWrapper::instance()->general_settings;
 		s->setDefaultFilename(filename);
@@ -1116,17 +1136,16 @@ void QMLManager::openNoCloudRepo()
 void QMLManager::saveChangesLocal()
 {
 	if (unsaved_changes()) {
-		if (credentialStatus() == CS_NOCLOUD) {
-			if (same_string(existing_filename, "")) {
+		if (m_credentialStatus == CS_NOCLOUD) {
+			if (empty_string(existing_filename)) {
 				char *filename = NOCLOUD_LOCALSTORAGE;
-				if (git_create_local_repo(filename))
-					appendTextToLog(get_error_string());
+				git_create_local_repo(filename);
 				set_filename(filename);
 				auto s = SettingsObjectWrapper::instance()->general_settings;
 				s->setDefaultFilename(filename);
 				s->setDefaultFileBehavior(LOCAL_DEFAULT_FILE);
 			}
-		} else if (!loadFromCloud()) {
+		} else if (!m_loadFromCloud) {
 			// this seems silly, but you need a common ancestor in the repository in
 			// order to be able to merge che changes later
 			appendTextToLog("Don't save dives without loading from the cloud, first.");
@@ -1140,9 +1159,7 @@ void QMLManager::saveChangesLocal()
 		bool glo = prefs.git_local_only;
 		prefs.git_local_only = true;
 		if (save_dives(existing_filename)) {
-			QString errorString(get_error_string());
-			appendTextToLog(errorString);
-			setNotificationText(errorString);
+			setNotificationText(consumeError());
 			set_filename(NULL);
 			prefs.git_local_only = glo;
 			alreadySaving = false;
@@ -1174,7 +1191,7 @@ void QMLManager::saveChangesCloud(bool forceRemoteSync)
 	if (prefs.git_local_only && !forceRemoteSync)
 		return;
 
-	if (!loadFromCloud()) {
+	if (!m_loadFromCloud) {
 		appendTextToLog("Don't save dives without loading from the cloud, first.");
 		return;
 	}
@@ -1244,6 +1261,7 @@ void QMLManager::deleteDive(int id)
 	}
 	DiveListModel::instance()->removeDiveById(id);
 	delete_single_dive(get_idx_by_uniq_id(id));
+	DiveListModel::instance()->resetInternalData();
 	changesNeedSaving();
 }
 
@@ -1326,16 +1344,9 @@ void QMLManager::setLogText(const QString &logText)
 
 void QMLManager::appendTextToLog(const QString &newText)
 {
-	if (!timer.isValid())
-		timer.start();
 	qDebug() << QString::number(timer.elapsed() / 1000.0,'f', 3) + ": " + newText;
 }
 
-bool QMLManager::locationServiceEnabled() const
-{
-	return m_locationServiceEnabled;
-}
-
 void QMLManager::setLocationServiceEnabled(bool locationServiceEnabled)
 {
 	m_locationServiceEnabled = locationServiceEnabled;
@@ -1343,11 +1354,6 @@ void QMLManager::setLocationServiceEnabled(bool locationServiceEnabled)
 	emit locationServiceEnabledChanged();
 }
 
-bool QMLManager::locationServiceAvailable() const
-{
-	return m_locationServiceAvailable;
-}
-
 void QMLManager::setLocationServiceAvailable(bool locationServiceAvailable)
 {
 	appendTextToLog(QStringLiteral("location service is ") + (locationServiceAvailable ? QStringLiteral("available") : QStringLiteral("not available")));
@@ -1360,11 +1366,6 @@ void QMLManager::hasLocationSourceChanged()
 	setLocationServiceAvailable(locationProvider->hasLocationsSource());
 }
 
-bool QMLManager::verboseEnabled() const
-{
-	return m_verboseEnabled;
-}
-
 void QMLManager::setVerboseEnabled(bool verboseMode)
 {
 	m_verboseEnabled = verboseMode;
@@ -1373,55 +1374,30 @@ void QMLManager::setVerboseEnabled(bool verboseMode)
 	emit verboseEnabledChanged();
 }
 
-QString QMLManager::cloudPassword() const
-{
-	return m_cloudPassword;
-}
-
 void QMLManager::setCloudPassword(const QString &cloudPassword)
 {
 	m_cloudPassword = cloudPassword;
 	emit cloudPasswordChanged();
 }
 
-QString QMLManager::cloudPin() const
-{
-	return m_cloudPin;
-}
-
 void QMLManager::setCloudPin(const QString &cloudPin)
 {
 	m_cloudPin = cloudPin;
 	emit cloudPinChanged();
 }
 
-QString QMLManager::cloudUserName() const
-{
-	return m_cloudUserName;
-}
-
 void QMLManager::setCloudUserName(const QString &cloudUserName)
 {
 	m_cloudUserName = cloudUserName.toLower();
 	emit cloudUserNameChanged();
 }
 
-int QMLManager::distanceThreshold() const
-{
-	return m_distanceThreshold;
-}
-
 void QMLManager::setDistanceThreshold(int distance)
 {
 	m_distanceThreshold = distance;
 	emit distanceThresholdChanged();
 }
 
-int QMLManager::timeThreshold() const
-{
-	return m_timeThreshold;
-}
-
 void QMLManager::setTimeThreshold(int time)
 {
 	m_timeThreshold = time;
@@ -1444,11 +1420,6 @@ QString QMLManager::theme() const
 	return s.value("currentTheme", "Blue").toString();
 }
 
-bool QMLManager::loadFromCloud() const
-{
-	return m_loadFromCloud;
-}
-
 void QMLManager::syncLoadFromCloud()
 {
 	QSettings s;
@@ -1465,22 +1436,12 @@ void QMLManager::setLoadFromCloud(bool done)
 	emit loadFromCloudChanged();
 }
 
-QString QMLManager::startPageText() const
-{
-	return m_startPageText;
-}
-
 void QMLManager::setStartPageText(const QString& text)
 {
 	m_startPageText = text;
 	emit startPageTextChanged();
 }
 
-QMLManager::cloud_status_qml QMLManager::credentialStatus() const
-{
-	return m_credentialStatus;
-}
-
 void QMLManager::setCredentialStatus(const cloud_status_qml value)
 {
 	if (m_credentialStatus != value) {
@@ -1495,11 +1456,6 @@ void QMLManager::setCredentialStatus(const cloud_status_qml value)
 	}
 }
 
-QMLManager::cloud_status_qml QMLManager::oldStatus() const
-{
-	return m_oldStatus;
-}
-
 void QMLManager::setOldStatus(const cloud_status_qml value)
 {
 	if (m_oldStatus != value) {
@@ -1549,22 +1505,12 @@ QString QMLManager::getGpsFromSiteName(const QString& siteName)
 	return "";
 }
 
-QString QMLManager::notificationText() const
-{
-	return m_notificationText;
-}
-
 void QMLManager::setNotificationText(QString text)
 {
 	m_notificationText = text;
 	emit notificationTextChanged();
 }
 
-bool QMLManager::syncToCloud() const
-{
-	return m_syncToCloud;
-}
-
 void QMLManager::setSyncToCloud(bool status)
 {
 	m_syncToCloud = status;
@@ -1575,22 +1521,12 @@ void QMLManager::setSyncToCloud(bool status)
 	emit syncToCloudChanged();
 }
 
-int QMLManager::updateSelectedDive() const
-{
-	return m_updateSelectedDive;
-}
-
 void QMLManager::setUpdateSelectedDive(int idx)
 {
 	m_updateSelectedDive = idx;
 	emit updateSelectedDiveChanged();
 }
 
-int QMLManager::selectedDiveTimestamp() const
-{
-	return m_selectedDiveTimestamp;
-}
-
 void QMLManager::setSelectedDiveTimestamp(int when)
 {
 	m_selectedDiveTimestamp = when;
@@ -1623,55 +1559,24 @@ void QMLManager::quit()
 	QApplication::quit();
 }
 
-QStringList QMLManager::suitInit() const
+QStringList QMLManager::suitList() const
 {
-	QStringList suits;
-	struct dive *d;
-	int i = 0;
-	for_each_dive (i, d) {
-		QString temp = d->suit;
-		if (!temp.isEmpty())
-			suits << d->suit;
-	}
-	suits.removeDuplicates();
-	suits.sort();
-	return suits;
+	return suitModel.stringList();
 }
 
-QStringList QMLManager::buddyInit() const
+QStringList QMLManager::buddyList() const
 {
-	QStringList buddies;
-	struct dive *d;
-	int i = 0;
-	for_each_dive (i, d) {
-		QString temp = d->buddy;
-		if (!temp.isEmpty() && !temp.contains(",")){
-			buddies << d->buddy;
-		}
-		else if (!temp.isEmpty()){
-			QRegExp sep("(,\\s)");
-			QStringList tempList = temp.split(sep);
-			buddies << tempList;
-		}
-	}
-	buddies.removeDuplicates();
-	buddies.sort();
-	return buddies;
+	return buddyModel.stringList();
 }
 
-QStringList QMLManager::divemasterInit() const
+QStringList QMLManager::divemasterList() const
 {
-	QStringList divemasters;
-	struct dive *d;
-	int i = 0;
-	for_each_dive (i, d) {
-		QString temp = d->divemaster;
-		if (!temp.isEmpty())
-			divemasters << d->divemaster;
-	}
-	divemasters.removeDuplicates();
-	divemasters.sort();
-	return divemasters;
+	return divemasterModel.stringList();
+}
+
+QStringList QMLManager::locationList() const
+{
+	return locationModel.allSiteNames();
 }
 
 QStringList QMLManager::cylinderInit() const
@@ -1681,7 +1586,7 @@ QStringList QMLManager::cylinderInit() const
 	int i = 0;
 	for_each_dive (i, d) {
 		for (int j = 0; j < MAX_CYLINDERS; j++) {
-			if (! same_string(d->cylinder[j].type.description, ""))
+			if (!empty_string(d->cylinder[j].type.description))
 				cylinders << d->cylinder[j].type.description;
 		}
 	}
@@ -1690,33 +1595,18 @@ QStringList QMLManager::cylinderInit() const
 	return cylinders;
 }
 
-bool QMLManager::showPin() const
-{
-	return m_showPin;
-}
-
 void QMLManager::setShowPin(bool enable)
 {
 	m_showPin = enable;
 	emit showPinChanged();
 }
 
-QString QMLManager::progressMessage() const
-{
-	return m_progressMessage;
-}
-
 void QMLManager::setProgressMessage(QString text)
 {
 	m_progressMessage = text;
 	emit progressMessageChanged();
 }
 
-bool QMLManager::libdcLog() const
-{
-	return m_libdcLog;
-}
-
 void QMLManager::setLibdcLog(bool value)
 {
 	m_libdcLog = value;
@@ -1724,22 +1614,12 @@ void QMLManager::setLibdcLog(bool value)
 	emit libdcLogChanged();
 }
 
-bool QMLManager::developer() const
-{
-	return m_developer;
-}
-
 void QMLManager::setDeveloper(bool value)
 {
 	m_developer = value;
 	emit developerChanged();
 }
 
-bool QMLManager::btEnabled() const
-{
-	return m_btEnabled;
-}
-
 void QMLManager::setBtEnabled(bool value)
 {
 	m_btEnabled = value;
