@@ -82,7 +82,7 @@ void DivePlannerPointsModel::loadFromDive(dive *d)
 	struct divecomputer *dc = &(d->dc);
 	recalc = false;
 	CylindersModel::instance()->updateDive();
-	duration_t lasttime = {};
+	duration_t lasttime = { 0 };
 	duration_t lastrecordedtime = {};
 	duration_t newtime = {};
 	free_dps(&diveplan);
@@ -108,6 +108,8 @@ void DivePlannerPointsModel::loadFromDive(dive *d)
 	int cylinderid = 0;
 	last_sp.mbar = 0;
 	for (int i = 0; i < plansamples - 1; i++) {
+		if (dc->last_manual_time.seconds && dc->last_manual_time.seconds > 120 && lasttime.seconds >= dc->last_manual_time.seconds)
+			break;
 		while (j * plansamples <= i * dc->samples) {
 			const sample &s = dc->sample[j];
 			if (s.time.seconds != 0 && (!hasMarkedSamples || s.manually_entered)) {
@@ -130,7 +132,8 @@ void DivePlannerPointsModel::loadFromDive(dive *d)
 		}
 	}
 	// make sure we get the last point right so the duration is correct
-	if (!hasMarkedSamples) addStop(0, d->dc.duration.seconds,cylinderid, last_sp.mbar, true);
+	if (!hasMarkedSamples && !dc->last_manual_time.seconds)
+		addStop(0, d->dc.duration.seconds,cylinderid, last_sp.mbar, true);
 	recalc = oldRec;
 	emitDataChanged();
 }
@@ -151,8 +154,9 @@ void DivePlannerPointsModel::setupCylinders()
 			if (!cylinder_none(&(displayed_dive.cylinder[i])))
 				return;		// We have at least one cylinder
 	}
-	if (!same_string(prefs.default_cylinder, "")) {
+	if (!empty_string(prefs.default_cylinder)) {
 		fill_default_cylinder(&displayed_dive.cylinder[0]);
+		displayed_dive.cylinder[0].start = displayed_dive.cylinder[0].type.workingpressure;
 	}
 	if (cylinder_none(&displayed_dive.cylinder[0])) {
 		// roughly an AL80
@@ -177,26 +181,6 @@ bool DivePlannerPointsModel::updateMaxDepth()
 	return (displayed_dive.maxdepth.mm != prevMaxDepth);
 }
 
-QStringList &DivePlannerPointsModel::getGasList()
-{
-	static QStringList list;
-	list.clear();
-	for (int i = 0; i < MAX_CYLINDERS; i++) {
-		cylinder_t *cyl = &displayed_dive.cylinder[i];
-		if (cylinder_nodata(cyl))
-			break;
-		/* Check if we have the same gasmix two or more times
-		 * If yes return more verbose string */
-		int same_gas = same_gasmix_cylinder(cyl, i, &displayed_dive, true);
-		if (same_gas == -1)
-			list.push_back(get_gas_string(cyl->gasmix));
-		else
-			list.push_back(get_gas_string(cyl->gasmix) + QString(" (%1 %2 ").arg(tr("cyl.")).arg(i + 1) +
-				cyl->type.description + ")");
-	}
-	return list;
-}
-
 void DivePlannerPointsModel::removeDeco()
 {
 	bool oldrec = setRecalc(false);
