@@ -11,6 +11,6 @@ echo "Submitting the folloing AppImage for continuous build release:"
 ls -lh Subsurface*.AppImage
 
 # get and run the upload script
-wget -c https://github.com/probonopd/uploadtool/raw/master/upload.sh
+wget -c https://raw.githubusercontent.com/dirkhh/uploadtool/master/upload.sh
 bash ./upload.sh Subsurface*.AppImage Subsurface*.AppImage.zsync
 
